@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006 - 2016
+  Copyright (c) 2006 - 2017
   CLST  - Radboud University
   ILK   - Tilburg University
 
@@ -710,12 +710,8 @@ namespace folia {
   class AllowGenerateID: public virtual FoliaElement {
   public:
     void setMaxId( FoliaElement * );
-    int getMaxId( const std::string& );
-    const std::string generateId( const std::string& tag ){
-      return IDgen( tag, this );
-    }
+    const std::string generateId( const std::string& tag );
   private:
-    std::string IDgen( const std::string&, const FoliaElement* );
     std::map<std::string, int> id_map;
   };
 
